r665: Renaming product from "BugStrike" to "Bugdar"
authorRobert Sesek <rsesek@bluestatic.org>
Thu, 22 Dec 2005 19:13:08 +0000 (19:13 +0000)
committerRobert Sesek <rsesek@bluestatic.org>
Thu, 22 Dec 2005 19:13:08 +0000 (19:13 +0000)
57 files changed:
admin/admin-bw.css
admin/admin.css
admin/autoaction.php
admin/field.php
admin/global.php
admin/index.php
admin/jump.php
admin/language.php
admin/permission.php
admin/priority.php
admin/product.php
admin/resolution.php
admin/setting.php
admin/severity.php
admin/status.php
admin/user.php
admin/usergroup.php
admin/userhelp.php
attachment.php
docs/datatools.php
editcomment.php
editreport.php
favourite.php
global.php
help.php
includes/adminfunctions.php
includes/class_history.php
includes/class_message_reporter.php
includes/class_pagination.php
includes/config.php.new
includes/functions.php
includes/functions_datastore.php
includes/functions_product.php
includes/init.php
includes/language.php
includes/permissions.php
includes/settings.php
index.php
install/global.php
install/install.css
install/install.php
install/schema.php
login.php
newcomment.php
newreport.php
register.php
search.php
showhistory.php
showreport.php
templates/box.css
templates/fields.css
templates/footer.tpl
templates/global.css
templates/report.css
userctrl.php
viewattachment.php
vote.php

index 88d117f6b70743de1c371c67158de2cbf005a095..9a7a71cb45ed698f9a5fedaba5279c87f3dd754d 100755 (executable)
@@ -1,4 +1,4 @@
-/* Admin CSS Class for BugStrike [#]version[#] */
+/* Admin CSS Class for Bugdar [#]version[#] */
 /* (c) 2002 - [#]year[#] Iris Studios, Inc.*/
 
 /* ################################################################### */
index d2107d1d00ec6bdc6cb68892159c7830fe6132e7..840087083c8e2b3e581ae45b8b27d50eab7f15c8 100755 (executable)
@@ -1,4 +1,4 @@
-/* Admin CSS Class for BugStrike [#]version[#] */
+/* Admin CSS Class for Bugdar [#]version[#] */
 /* (c) 2002 - [#]year[#] Iris Studios, Inc.*/
 
 /* ################################################################### */
index fc7ccb0cef848175d862e252a1fef4f7cdb94ef6..a2810f669be711e1867d86a46d488fd7d6faf093 100644 (file)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 031d71a78ee61839830b282375a0376074b26b5d..74b812407b56233c10504e99269ffd19af1e33e0 100644 (file)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 6f460a7af00ab381aa58e0649a1077b9ffcd39f2..9dc2fafaeced39a9896ff9a61796a72e6d025ac8 100755 (executable)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
@@ -25,7 +25,7 @@ $globalnav = array(
        ),
        
        $lang->string('Options') => array(
-               $lang->string('BugStrike Settings') => 'setting.php',
+               $lang->string('Bugdar Settings') => 'setting.php',
                $lang->string('Manage Languages') => 'language.php',
                $lang->string('Edit User Help') => 'userhelp.php'
        ),
@@ -63,7 +63,7 @@ function admin_login()
        
        $admin->form_start('../login.php', 'cplogin', false, 'cplogin');
        $admin->table_start(true, '425');
-       $admin->table_head($bugsys->lang->string('Login to BugStrike'));
+       $admin->table_head($bugsys->lang->string('Login to Bugdar'));
        $admin->row_input($bugsys->lang->string('Email'), 'email', $bugsys->userinfo['email'], 2, 35, false, false, 'middle');
        $admin->row_input($bugsys->lang->string('Password'), 'password', '', 2, 35, false, true, 'middle');
        $admin->row_submit('', $bugsys->lang->string('Login'));
index 546042d624dc8761a5d45a12443f307238834695..7ca5e0ab3d6da7277ac3cafd373d79de4676c609 100755 (executable)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
@@ -15,7 +15,7 @@ require_once('./global.php');
 $admin->page_start('Index');
 
 $admin->table_start(true, '300');
-$admin->table_head($lang->string('BugStrike Administration Menu'), 2, 'admin_index');
+$admin->table_head($lang->string('Bugdar Administration Menu'), 2, 'admin_index');
 
 $navdata = '<ul>';
 foreach  ($globalnav AS $group => $links)
index f509da0810faad292d96b65df05fd82812f7a679..2327d55c97adaad006bce82f688d172b2d935d23 100755 (executable)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index ea474c99603efca913ff3def95d6b74a4dc00ec5..badc8a1479870b17be6d0b797f4c96ffd6cb27b2 100644 (file)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index d22c6e1cffe00056fcbce0f211e3bf829ea0d303..8d1d079b408b0cf86e8cd84f10a59be6a269f4a6 100755 (executable)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index ef89676958d638319574b7f5a178fa5570a8181b..eebabe1253a61edbb7125c77e5c3e74b18e65bf5 100755 (executable)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index f73b2fcd7b0d5853b4c3a89980340641c5e049b4..1ef2e51e841f882944e09d9b63b0599d096e899e 100755 (executable)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index ee2dda20bc038b1bf84c3f967db81ad61c576b3e..6de5a87ab6066e3dd0bf49125e69aa1b3476a125 100755 (executable)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index ce187731244e10f47c1588f731ad4dc8f788336e..9917c20ef900242591365c227aa1d01c0edd2a84 100755 (executable)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 82050fcb62d0043d2bf4d91ca49fc917b095c1ef..a9e9d925365c1516c96242421194935d59447279 100755 (executable)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 2f769dcc3a20675a3a04c375b0c8ffe6b4c1940f..3be221bcb5e963f22b19adbc267d01f93febdc3f 100755 (executable)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 9ff0168725bcbb8a149aeed14a2aaac58c6871b6..9c494553196df0b6d8b80b645b58011c6877a6b6 100644 (file)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 6c2168f2fd9126960386c4ce84a4aff65b6e5c6f..899e2d115793df8b81436b83ee44f137df5c1c04 100755 (executable)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 5d9524b944cdee60d14c80779bd1f1e8863a1445..651450210fe4032cd34eab82c6b5f46c8eec0ef3 100755 (executable)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index bbd62f4f76530b95c9edcd4930c3d0c96c29012e..76fff065bca66ff9c00109a7c1df5bce7b80ed39 100755 (executable)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 9aeb7e1e10b2ead5967bd525b963f1e943781e76..b22048e6a2ed7f18bfffc5b514b1356081303b9c 100644 (file)
@@ -40,7 +40,7 @@ $THELIST = array(
 
 <h2>Data Tools</h2>
 
-Here you can either export or import the standard data tables for BugStrike. These include things such as usergroups, priorities, etc.
+Here you can either export or import the standard data tables for Bugdar. These include things such as usergroups, priorities, etc.
 
 <h3>[<strong><a href="datatools.php?do=export">Export</a></strong>] [<strong><a href="datatools.php?do=import">Import</a></strong>] [<strong><a href="datatools.php?do=view">View</a></strong>]</h3>
 
index f351b0859d773d9ce3ab521b7bf9dec177d029fc..bac49018e1cd7d8913c001bcd4144df4e5bca5d6 100644 (file)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index ea9eeba940cbfd74e5f6992d9d7f32c3e9ba178c..28ccfca5b5b0cef1bfd0f2f5982c8c8a5579a511 100644 (file)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 28b0f92b82260d68b520f8419458f0405951b088..9c11c8512b65a769b42a394a5f25b5ca70203cd7 100644 (file)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index ee41abab97e066869a74d0d1630e9866b35649d4..2b7c0461969d60c41e98aaeffe41f420bc5ba6c9 100755 (executable)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 82a6fdf75ec11a242dbf10d7bb22f82ed87dae7c..92cdaaad20addc60af74b86ad6e847b3f6da1b57 100644 (file)
--- a/index.php
+++ b/index.php
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 5b1af5e9a42773aa5c566a0e72ee64c907851534..2c25e1d7dab674702abbbd32726f99fd8c2abdd3 100644 (file)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
@@ -32,7 +32,7 @@ define('ISSO_CHECK_POST_REFERER', 1);
 
 require_once($pathtoisso . 'kernel.php');
 $bugsys =& $_isso;
-$bugsys->application = 'BugStrike';
+$bugsys->application = 'Bugdar';
 $bugsys->apppath = $bugsys->fetch_sourcepath(getcwd());
 $bugsys->appversion = '[#]version[#]';
 $bugsys->debug = $debug;
@@ -79,7 +79,7 @@ function page_start()
 <head>
        <meta http-equiv="content-type" content="text/html; charset=iso-8859-1" />
        <link rel="stylesheet" href="install.css" media="screen" />
-       <title>BugStrike Installer</title>
+       <title>Bugdar Installer</title>
 </head>
 <body>
 
index b91fb80516a60f8da476d38d2d4bd8d14b72fd97..12b39b7f0e04b4f846418e7489dd090d7400a106 100644 (file)
@@ -1,6 +1,6 @@
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index a290741196841d7f7045d9463b7cc0e6da8e97ef..9dd64e70b141a22c684c4600e8fd8a0f26619f13 100644 (file)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
@@ -22,9 +22,9 @@ page_start();
 if ($bugsys->in['mark'] == 0)
 {
 ?>
-<h1>Welcome to BugStrike</h1>
+<h1>Welcome to Bugdar</h1>
 
-<p>This installer will take you through the procedure of setting up your BugStrike installation. If you are seeing this message, that means that your configuration file was read properly and that your database is accessible.</p>
+<p>This installer will take you through the procedure of setting up your Bugdar installation. If you are seeing this message, that means that your configuration file was read properly and that your database is accessible.</p>
 
 <p>The following steps will initialize your database, place the default settings and data in your database, and finally ask you to enter in some settings to allow you to access the system when the installer finishes.</p>
 
@@ -59,7 +59,7 @@ if ($bugsys->in['mark'] == 2)
 ?>
 <h1>Loading Default Data</h1>
 
-<p>Default table data for usergroups, statuses, priorities, and other various options are being loaded. This will allow you to use BugStrike with minimal setup.</p>
+<p>Default table data for usergroups, statuses, priorities, and other various options are being loaded. This will allow you to use Bugdar with minimal setup.</p>
 
 <?php
        
@@ -198,7 +198,7 @@ if ($bugsys->in['mark'] == 7)
 ?>
 <h1>Cache Data</h1>
 
-<p>In order to make BugStrike as efficient as possible, the system caches the portions of data it can. This reduces the load of your server without compromising usability. Currently the caches are being built.</p>
+<p>In order to make Bugdar as efficient as possible, the system caches the portions of data it can. This reduces the load of your server without compromising usability. Currently the caches are being built.</p>
 <?php
        
        require_once('./includes/permissions.php');
index 387083796bff04d6222eb93c55e252a957352490..7332310a6bc5a2eb8bca09441f305f21cfb849b5 100644 (file)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index b2e9240f7411b9e0a18467a3b18c04156a917a26..370393d0b82208f5ed9bc46d8a59ed6d4d8dec8e 100755 (executable)
--- a/login.php
+++ b/login.php
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 4b62510e5dafe53dc3f44f789ceb33be1166b3c2..20df7b5c306b76c0df4a8d37093baeb6fe18c9cb 100644 (file)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 9fe91168f544c5ae521f4bda9f456d8e5365941e..07ba60a9419baea5ab0811cf666d554295d5240b 100755 (executable)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index f91efe9bcf641808345a50751f836b7f5975b93a..d2eea5f70eb5d6bae937e1d47f0018b587b3a009 100755 (executable)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index fcf5f66ed5d6e5c3fc187113f064a55c5fdcfaf9..e86d2dcc067e9b287c1796f206a2522c354ded4d 100644 (file)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 0b1c985542f9c7e25cc9070cc14a3def9af276ef..88cd6d6a236f27d4e56bc7448e078e33b0c395db 100644 (file)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 7cd740d991f1b98f45cb1eacd87ccf70f2c4ecf8..f0ebe9e581ea715acf2d1841bb465b7c403feb20 100644 (file)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 4dde8a62e9059e47dc9f4f516ea6cd7fdb43f3b6..b50bb1fa249d27afdc8a572f8fbdd6021edb5984 100644 (file)
@@ -1,6 +1,6 @@
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index d9e965f04f4857808be869e49605b4b57628f0fc..808be0c3c2e4dde249f96e1fefaf79229111386f 100644 (file)
@@ -1,6 +1,6 @@
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 9b1f16944dec30e04e1c0804d58d186d23780199..c4265d23ad18312d72bbb788a09212a2fdac87cd 100644 (file)
@@ -1,7 +1,7 @@
 </div>
 
 <div id="copyright">
-       <div><lang 1="$version">{@"Powered by BugStrike %1$s"}</lang></div>
+       <div><lang 1="$version">{@"Powered by Bugdar %1$s"}</lang></div>
        <div>{@"Copyright"} &copy;2002 - $year, Iris Studios, Inc.</div>
 </div>
 
index 2feaa56449d3505decc8876afd95f4db63d49998..f48192f47554918673a73066c8edf2a6c3998f00 100644 (file)
@@ -1,6 +1,6 @@
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 461c82c2021b55e804e2cdf8b917425a8421a2d1..c04e5ae27702bc165344cf240f8a890588191b9a 100644 (file)
@@ -1,6 +1,6 @@
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 736d7cb0b364ac417ec9f1256788e7d64c5392d4..1f150d9d8c1b03eedc8e9bea0a65cc52039877e5 100644 (file)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 23498cc099db8c156b931d2a734bc985fd0ba5b2..e790e692fb9ef07c2e7d2d51fb6c032de0dacfd1 100755 (executable)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 8662c719a8ccc3afe06280decade65a4e2a91a39..5aae2524da0a2b5101587946e554ac53e0673245 100644 (file)
--- a/vote.php
+++ b/vote.php
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
--- a/help.php
+++ b/help.php
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 284011830897b3ea586c7e37ab2fd129f82b6fa2..f01ecf93d4e8570c4f750ba7deca3ffdaab32bfe 100755 (executable)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
@@ -71,7 +71,7 @@ EOD;
                        return;
                }
                
-               $title = sprintf($bugsys->lang->string('BugStrike - Administration - %1$s'), $actiontitle);
+               $title = sprintf($bugsys->lang->string('Bugdar - Administration - %1$s'), $actiontitle);
                
                echo "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">\n";
                echo "<html xmlns=\"http://www.w3.org/1999/xhtml\">\n<head>";
@@ -144,7 +144,7 @@ EOD;
        {
                global $bugsys;
                
-               $copyright = "\n<br />\n<p align=\"center\" class=\"copyright\">\n\t<a href=\"http://www.iris-studios.com\" target=\"_blank\">BugStrike " . $bugsys->options['trackerversion'] . ", &copy; 2002 - " . date('Y') . " Iris Studios, Inc.</a>\n</p>";
+               $copyright = "\n<br />\n<p align=\"center\" class=\"copyright\">\n\t<a href=\"http://www.iris-studios.com\" target=\"_blank\">Bugdar " . $bugsys->options['trackerversion'] . ", &copy; 2002 - " . date('Y') . " Iris Studios, Inc.</a>\n</p>";
                                
                if (!defined('HIDE_SETUP'))
                {
@@ -176,8 +176,8 @@ EOD;
        function table_head($title, $colspan = 2, $help = null)
        {
                global $edoc;
-               $title = ($help ? "<a href=\"http://www.iris-studios.com/support/bugstrike/$help.html\" target=\"_blank\" style=\"cursor: help; text-decoration: none\">$title</a>" : $title);
-               $help = ($help ? "<span style=\"float: right\"><a href=\"http://www.iris-studios.com/support/bugstrike/$help.html\" target=\"_blank\" style=\"cursor: help; text-decoration: none; font-size: 9px; color: #FFFFFF\">Help</a></span>" : '');
+               $title = ($help ? "<a href=\"http://www.iris-studios.com/support/bugdar/$help.html\" target=\"_blank\" style=\"cursor: help; text-decoration: none\">$title</a>" : $title);
+               $help = ($help ? "<span style=\"float: right\"><a href=\"http://www.iris-studios.com/support/bugdar/$help.html\" target=\"_blank\" style=\"cursor: help; text-decoration: none; font-size: 9px; color: #FFFFFF\">Help</a></span>" : '');
                echo "<tr>\n\t<td class=\"tcat\" align=\"center\" colspan=\"$colspan\">$help<strong>$title</strong></td>\n</tr>\n";
        }
        
index 571613e077518fd5d02153f8b11d02f651302799..7648d78936c1c0059e32f60047f41e95faee8095 100644 (file)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 4f6a44bdf3f9edcd25d884b02be3a5bbfa58a92f..b54c788b715421ecef72976d5c109b1e7056460d 100755 (executable)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 2bb6d4de8a95cd5659d13b13b3557fd6377e9cb8..82a7d3f82d40039c2da6e7a6c849c7c4d34bb4a2 100644 (file)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index bc045a8d91f08f2f2a6b9ae762e04e766514f2a5..6030e519a0b4f889d3043d3fcbf3f31f7ef05ee3 100644 (file)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
@@ -34,7 +34,7 @@ $password = '';
 // ###################################################################
 // ///////////////////////// DATABASE NAME
 // -------------------------------------------------------------------
// This is the name of the MySQL database that BugStrike will
 // use to store information in. You or your host will have to make it.
 $database = 'bugdb';
 
index 018e121e8a9f7d79d179ee2ea1b4bc3878a6887e..364f377084f8fe1d781c5653a755ecb097f44c5c 100755 (executable)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 142ddfc0d7b19830c8a0e77e829923958a77c179..0fb10e91f4594c425920ee68143c570a401dd1ef 100755 (executable)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 7a04ae3e3bb33a7bd4b939662051d80415433999..4df8d39181062ef19c7d9a7a1cb90251fac10e66 100644 (file)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index d3391aa893295570c478a6a37d3da1cdafd82795..bc5df20736013ac666727ea0d3ac951532b10785 100755 (executable)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
@@ -30,7 +30,7 @@ define('ISSO_CHECK_POST_REFERER', 1);
 
 require_once($pathtoisso . 'kernel.php');
 $bugsys =& $_isso;
-$bugsys->application = 'BugStrike';
+$bugsys->application = 'Bugdar';
 $bugsys->apppath = $bugsys->fetch_sourcepath(getcwd());
 $bugsys->appversion = '[#]version[#]';
 $bugsys->debug = $debug;
@@ -136,7 +136,7 @@ $datef->fetch_offset();
 // mail system
 $bugsys->load('mail');
 $mail->from = $bugsys->options['webmasteremail'];
-$mail->fromname = $lang->string('BugStrike Notification');
+$mail->fromname = $lang->string('Bugdar Notification');
 
 // ###################################################################
 // load permissions
index 3ea89efde677221596709f20cf1d6c35b306d61d..fa1376c6153f060b1f5799496ba1eba40056e7e0 100644 (file)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 9accb484ed87902b9ddff4db34a7b02f14aaf1c0..91a7c8b0e5608fb5639afe551b01a5229ed86f00 100644 (file)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
index 202eab7477b0624a2b86264b170c462810770d19..2ba5c34aceea502780d3790f2d8eb6db6a2099da 100755 (executable)
@@ -1,7 +1,7 @@
 <?php
 /*=====================================================================*\
 || ################################################################### ||
-|| # BugStrike [#]version[#]
+|| # Bugdar [#]version[#]
 || # --------------------------------------------------------------- # ||
 || # Copyright ©2002-[#]year[#] by Iris Studios, Inc. All Rights Reserved. # ||
 || # This file may not be reproduced in any way without permission.  # ||
@@ -34,7 +34,7 @@ $password = '';
 // ///////////////////////// DATABASE NAME
 // -------------------------------------------------------------------
-// This is the name of the MySQL database that BugStrike will
+// This is the name of the MySQL database that Bugdar will
 // use to store information in. You or your host will have to make it.
 $database = 'bugdb';
index 78d8eeb633a9b4289dd118bb64f8ecfa3f8b17a6..d2a37e7bf9555c89dac047892556b1f3a1fb170f 100644 (file)